Learn R Programming

fritools (version 4.6.0)

check_ascii_file: Check the Number of Lines and Fields in a File

Description

Check the Number of Lines and Fields in a File

Usage

check_ascii_file(path, sep = ";")

Value

A list giving the number of lines, number of fields and an boolean indicating whether all lines have the same number of fields.

Arguments

path

Path to a file.

sep

A character separating the fields in the file.

See Also

Other CSV functions: bulk_read_csv(), bulk_write_csv(), csv, csv2csv()

Examples

Run this code
f <- tempfile()
write.csv2(mtcars, file = f)
check_ascii_file(f)

Run the code above in your browser using DataLab