Learn R Programming

fritools (version 4.6.0)

convert_umlauts_to_ascii: Convert German Umlauts to a More or Less Suitable `ascii` Representation

Description

Convert German Umlauts to a More or Less Suitable `ascii` Representation

Usage

convert_umlauts_to_ascii(x)

# S3 method for character convert_umlauts_to_ascii(x)

# S3 method for data.frame convert_umlauts_to_ascii(x)

Value

x with the umlauts converted to ascii.

Arguments

x

A string or data.frame.

See Also

Other German umlaut converters: convert_umlauts_to_tex(), convert_umlauts_to_utf8(), get_german_umlauts()

Examples

Run this code
string <- "this is \u00e4 string"
print(string)
print(convert_umlauts_to_ascii(string))
string <- "this is \u00e4 string"
df <- data.frame(v1 = c(string, "foobar"),
                 v2 = c("foobar", string), v3 = 3:4)
names(df)[3] <- "y\u00dfy"
convert_umlauts_to_ascii(df)

Run the code above in your browser using DataLab