Learn R Programming

fritools (version 4.6.0)

convert_umlauts_to_tex: Tex Codes for German Umlauts

Description

Convert German umlauts in a string to their plain TeX representation.

Usage

convert_umlauts_to_tex(x)

Value

A string with the umlauts converted to plain TeX.

Arguments

x

A string.

See Also

Other German umlaut converters: convert_umlauts_to_ascii(), convert_umlauts_to_utf8(), get_german_umlauts()

Examples

Run this code
string <- paste("this is \u00e4 string")
print(string)
print(convert_umlauts_to_tex(string))

Run the code above in your browser using DataLab