Learn R Programming

fritools (version 4.6.0)

convert_umlauts_to_utf8: Convert German Umlauts to a More or Less Suitable `utf8` Representation

Description

Convert German Umlauts to a More or Less Suitable `utf8` Representation

Usage

convert_umlauts_to_utf8(x)

# S3 method for character convert_umlauts_to_utf8(x)

# S3 method for data.frame convert_umlauts_to_utf8(x)

Value

x with the umlauts converted to utf8.

Arguments

x

A string or data.frame.

See Also

Other German umlaut converters: convert_umlauts_to_ascii(), convert_umlauts_to_tex(), get_german_umlauts()

Examples

Run this code
string <- "_(\xdcLH)"
print(string)
print(convert_umlauts_to_utf8(string))
string <- "this is _(\xdcLH) string"
df <- data.frame(v1 = c(string, "foobar"),
                 v2 = c("foobar", string), v3 = 3:4)
names(df)[3] <- "y_(\xdcLH)"
convert_umlauts_to_utf8(df)
convert_umlauts_to_ascii(convert_umlauts_to_utf8(df))

Run the code above in your browser using DataLab