get_session_string: Get a Session String

View source: R/get_session_string.R

get_session_stringR Documentation

Get a Session String

Description

I sometimes wan't to document the R session used in a string, so a need an excerpt of sessionInfo an Sys.time.

Usage

get_session_string()

Value

An excerpt of sessionInfo as a string.

See Also

Other version functions: get_package_version(), is_r_package_installed(), is_version_sufficient()

Examples

get_session_string()

fritools documentation built on Feb. 18, 2026, 9:06 a.m.