powered by
Check the Number of Lines and Fields in a File
check_ascii_file(path, sep = ";")
A list giving the number of lines, number of fields and an boolean indicating whether all lines have the same number of fields.
Path to a file.
A character separating the fields in the file.
Other CSV functions: bulk_read_csv(), bulk_write_csv(), csv, csv2csv()
bulk_read_csv()
bulk_write_csv()
csv
csv2csv()
f <- tempfile() write.csv2(mtcars, file = f) check_ascii_file(f)
Run the code above in your browser using DataLab