powered by
Convert German umlauts in a string to their plain TeX representation.
convert_umlauts_to_tex(x)
A string with the umlauts converted to plain TeX.
A string.
Other German umlaut converters: convert_umlauts_to_ascii(), convert_umlauts_to_utf8(), get_german_umlauts()
convert_umlauts_to_ascii()
convert_umlauts_to_utf8()
get_german_umlauts()
string <- paste("this is \u00e4 string") print(string) print(convert_umlauts_to_tex(string))
Run the code above in your browser using DataLab